@@ -1,20 +1,18 @@
 import datetime
 from os.path import dirname
-from typing import Union, Optional
+from sqlite3 import OperationalError
+from typing import Optional, Union
 
 import aiohttp
 import ujson as json
-from PIL import Image
-
 from nonebot.adapters.onebot.v11 import MessageSegment
-from nonebot.matcher import Matcher
 from nonebot.log import logger
+from nonebot.matcher import Matcher
+from nonebot_plugin_htmlrender import get_new_page as new_page, md_to_pic
 from sqlalchemy.schema import CreateTable
-from sqlite3 import OperationalError
-from nonebot_plugin_htmlrender import get_new_page as new_page
-from nonebot_plugin_htmlrender import md_to_pic
-from .model import sub_tournament, sqlite_pool, connect_database
-from .template import make_table, day_analyze_builder
+
+from .model import connect_database, sqlite_pool, sub_tournament
+from .template import day_analyze_builder, make_table, tournament_brief_builder
 
 api = "https://www.scoregg.com/services/api_url.php"
 afterMatchDetail = "https://img.scoregg.com/match/result/{}.json"
@@ -80,6 +78,12 @@ async def create_image(html: str, locator: str, wait: int = 0) -> bytes:
     return img_raw
 
 
+async def screenshot(url, locator):
+    async with new_page() as page:
+        await page.goto(url)
+        return await page.locator(locator).screenshot()
+
+
 class LoLMatch:
     tournament_available = []
     tournament_available_date = datetime.datetime(2021, 12, 1)
@@ -213,9 +217,11 @@ class LoLMatch:
             return []
 
     @classmethod
-    async def get_week_matches(cls, date: str = None) -> Optional[dict]:
+    async def get_week_matches(cls, date: str = None, tournament_id: int = None) -> Optional[dict]:
         """
         获取属于所给日期的一周的比赛信息
+
+        :param tournament_id: 可选的联赛id
         :param date: 不提供时默认今天
         :return:
         """
@@ -224,6 +230,10 @@ class LoLMatch:
                 match_params.pop("date", 0)
             else:
                 match_params["date"] = date
+            if tournament_id is None:
+                match_params.pop("tournament_id", 0)
+            else:
+                match_params["tournament_id"] = tournament_id
             async with session.post(url=api, data=match_params) as resp:
                 try:
                     data_json = json.loads(await resp.read())
@@ -292,6 +302,36 @@ class LoLMatch:
         else:
             return MessageSegment.text("本周无比赛.")
 
+    @classmethod
+    async def show_tournament_match(cls, tournament_id):
+        """
+        处理过去一周指定联赛ID的所有比赛
+
+        :return:
+        """
+
+        table = """<caption><b>近期赛果</b></caption><tr><th width="100px">比赛日期</th>
+        <th width="80px">结果ID</th><th width="220px" bgcolor=#FAEBD7>对战双方</th></tr>"""
+        result = await cls.get_week_matches(tournament_id=tournament_id)
+        count = 0
+        flag = False
+        while count < 5:
+            for day in result.values().__reversed__():
+                if not isinstance(day, dict):
+                    continue
+                for match in day["info"][str(tournament_id)]["list"]:
+                    if match["has_real_time"] == 0:
+                        break
+                    count += 1
+                    table += f"""<tr><td>{match["start_date"]}</td><td>{match["match_id"]}</td>
+        <td> {match["team_a_short_name"]} {match["team_a_win"]} <font color=red>VS</font> {match["team_b_win"]} {match["team_b_short_name"]}</td></tr>"""
+            if flag:
+                break
+            flag = True
+            prev = datetime.datetime.now() - datetime.timedelta(days=7)
+            result = await cls.get_week_matches(tournament_id=tournament_id, date=str(prev.date()))
+        return MessageSegment.image(await create_image(tournament_brief_builder(table), "table"))
+
     @classmethod
     async def get_match_details(cls, match_id: Union[int, str]) -> Optional[dict]:
         """
